Documentation
¶
Overview ¶
Package os provides Go bindings for the os framework.
Coordinate the scheduling and synchronization of your app’s tasks, and log information to the console to diagnose issues.
Essentials ¶
- Reading UNIX Manual Pages: Use the Terminal app to read the documentation for low-level UNIX tools and APIs.
Logs ¶
- Logging: Capture telemetry from your app for debugging and performance analysis using the unified logging system. (Os_signpost_id_t)
Task Management ¶
- Workgroups: Schedule one or more threads to run at regular intervals and before specific deadlines.
- Synchronization: Access low-level synchronization mechanisms to control state across threads.
Memory ¶
- os_proc_available_memory: Determines the amount of memory available to the current app.
- Os_block_t: A block that takes no arguments and returns no value.
- Os_function_t: A pointer to a function.
- Os_release
- Os_retain
Functions ¶
- os_lockdown_mode_enabled
- Os_security_config_get
- Os_security_config_get_for_proc
- Os_security_config_get_for_task
Macros ¶
- API_OBSOLETED
- API_OBSOLETED_BEGIN
- API_OBSOLETED_END
- API_OBSOLETED_WITH_REPLACEMENT
- API_OBSOLETED_WITH_REPLACEMENT_BEGIN
- API_OBSOLETED_WITH_REPLACEMENT_END
- LOG_SWIFT_NAME
- LOG_SWIFT_NEWTYPE
- OS_LOG_STRING_SECTION
- OS_WORKGROUP_ENUM_API_DEPRECATED_WITH_REPLACEMENT
Enumerations ¶
Key Types ¶
- OS_object
- OS_os_workgroup
- OS_os_workgroup_interval
- OS_os_workgroup_parallel
- OSLog - A container of related log messages.
Code generated from Apple documentation. DO NOT EDIT.
Index ¶
- func NewOSBlock(handler OSBlock) (objc.ID, func())
- func Os_activity_apply(activity Os_activity_t, block Os_block_t)
- func Os_activity_apply_f(activity Os_activity_t, context unsafe.Pointer, function Os_function_t)
- func Os_activity_scope_enter(activity Os_activity_t, state Os_activity_scope_state_t)
- func Os_activity_scope_leave(state Os_activity_scope_state_t)
- func Os_log_type_enabled(oslog Os_log_t, type_ Os_log_type_t) bool
- func Os_release(object unsafe.Pointer)
- func Os_retain(object unsafe.Pointer) unsafe.Pointer
- func Os_security_config_get_for_proc(pid int32, config *OsSecurityConfig) int
- func Os_security_config_get_for_task(task kernel.Task_t, config *OsSecurityConfig) int
- func Os_signpost_enabled(log Os_log_t) bool
- func Os_sync_wait_on_address(addr unsafe.Pointer, value uint64, size uintptr, flags OsSyncWaitOnAddress) int
- func Os_sync_wait_on_address_with_deadline(addr unsafe.Pointer, value uint64, size uintptr, flags OsSyncWaitOnAddress, ...) int
- func Os_sync_wait_on_address_with_timeout(addr unsafe.Pointer, value uint64, size uintptr, flags OsSyncWaitOnAddress, ...) int
- func Os_sync_wake_by_address_all(addr unsafe.Pointer, size uintptr, flags OsSyncWakeByAddress) int
- func Os_sync_wake_by_address_any(addr unsafe.Pointer, size uintptr, flags OsSyncWakeByAddress) int
- func Os_unfair_lock_assert_not_owner(lock *[4]byte)
- func Os_unfair_lock_assert_owner(lock *[4]byte)
- func Os_unfair_lock_lock(lock Os_unfair_lock_t)
- func Os_unfair_lock_lock_with_flags(lock Os_unfair_lock_t, flags OsUnfairLockFlag)
- func Os_unfair_lock_trylock(lock Os_unfair_lock_t) bool
- func Os_unfair_lock_unlock(lock Os_unfair_lock_t)
- func Os_workgroup_cancel(wg Os_workgroup_t)
- func Os_workgroup_copy_port(wg Os_workgroup_t, mach_port_out *uint32) int
- func Os_workgroup_get_working_arena(wg Os_workgroup_t, index_out *Os_workgroup_index) unsafe.Pointer
- func Os_workgroup_interval_finish(wg Os_workgroup_interval_t, data Os_workgroup_interval_data_t) int
- func Os_workgroup_interval_start(wg Os_workgroup_interval_t, start uint64, deadline uint64, ...) int
- func Os_workgroup_interval_update(wg Os_workgroup_interval_t, deadline uint64, data Os_workgroup_interval_data_t) int
- func Os_workgroup_join(wg Os_workgroup_t, token_out Os_workgroup_join_token_t) int
- func Os_workgroup_leave(wg Os_workgroup_t, token Os_workgroup_join_token_t)
- func Os_workgroup_max_parallel_threads(wg Os_workgroup_t, attr Os_workgroup_mpt_attr_t) int
- func Os_workgroup_set_working_arena(wg Os_workgroup_t, arena unsafe.Pointer, max_workers uint32, ...) int
- func Os_workgroup_testcancel(wg Os_workgroup_t) bool
- type IOSLog
- type IOS_object
- type IOS_os_workgroup
- type IOS_os_workgroup_interval
- type IOS_os_workgroup_parallel
- type OSActivity
- type OSActivityFlag
- type OSActivityID
- type OSActivityScopeState
- type OSBlock
- type OSClockid
- type OSFunction
- type OSLog
- type OSLogClass
- type OSLogType
- type OSSecurityConfig
- type OSSignpostID
- type OSSignpostType
- type OSSyncWaitOnAddressFlags
- type OSSyncWakeByAddressFlags
- type OSUnfairLock
- type OSUnfairLockFlags
- type OSWorkgroup
- type OSWorkgroupAttr
- type OSWorkgroupAttrS
- type OSWorkgroupIndex
- type OSWorkgroupInterval
- type OSWorkgroupIntervalData
- type OSWorkgroupIntervalDataS
- type OSWorkgroupJoinToken
- type OSWorkgroupJoinTokenS
- type OSWorkgroupMptAttr
- type OSWorkgroupMptAttrS
- type OSWorkgroupParallel
- type OSWorkgroupWorkingArenaDestructor
- type OS_object
- type OS_objectClass
- type OS_os_activity
- type OS_os_activityObject
- type OS_os_log
- type OS_os_logObject
- type OS_os_workgroup
- type OS_os_workgroupClass
- type OS_os_workgroup_interval
- type OS_os_workgroup_intervalClass
- type OS_os_workgroup_intervalProtocol
- type OS_os_workgroup_intervalProtocolObject
- type OS_os_workgroup_parallel
- type OS_os_workgroup_parallelClass
- type OS_os_workgroup_parallelProtocol
- type OS_os_workgroup_parallelProtocolObject
- type OsActivityFlag
- type OsClockMachAbsolute
- type OsLogType
- type OsSecurityConfig
- type OsSignpost
- type OsSyncWaitOnAddress
- type OsSyncWakeByAddress
- type OsUnfairLockFlag
- type Os_activity_flag_t
- type Os_activity_id_t
- type Os_activity_scope_state_s
- type Os_activity_scope_state_t
- type Os_activity_t
- type Os_block_t
- type Os_clockid_t
- type Os_function_t
- type Os_log_t
- type Os_log_type_t
- type Os_security_config_t
- type Os_signpost_id_t
- type Os_signpost_type_t
- type Os_sync_wait_on_address_flags_t
- type Os_sync_wake_by_address_flags_t
- type Os_unfair_lock_flags_t
- type Os_unfair_lock_t
- type Os_workgroup_attr_opaque_s
- type Os_workgroup_attr_s
- type Os_workgroup_attr_t
- type Os_workgroup_index
- type Os_workgroup_interval_data_opaque_s
- type Os_workgroup_interval_data_s
- type Os_workgroup_interval_data_t
- type Os_workgroup_interval_t
- type Os_workgroup_join_token_opaque_s
- type Os_workgroup_join_token_s
- type Os_workgroup_join_token_t
- type Os_workgroup_mpt_attr_s
- type Os_workgroup_mpt_attr_t
- type Os_workgroup_parallel_t
- type Os_workgroup_t
- type Os_workgroup_working_arena_destructor_t
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewOSBlock ¶
NewOSBlock wraps a Go OSBlock as an Objective-C block. The caller must defer the returned cleanup function.
func Os_activity_apply ¶
func Os_activity_apply(activity Os_activity_t, block Os_block_t)
Os_activity_apply execute a block using a given activity object.
See: https://developer.apple.com/documentation/os/os_activity_apply
func Os_activity_apply_f ¶
func Os_activity_apply_f(activity Os_activity_t, context unsafe.Pointer, function Os_function_t)
Os_activity_apply_f execute a function using a given activity object.
See: https://developer.apple.com/documentation/os/os_activity_apply_f
func Os_activity_scope_enter ¶
func Os_activity_scope_enter(activity Os_activity_t, state Os_activity_scope_state_t)
Os_activity_scope_enter switches the current activity, saving the existing execution context.
See: https://developer.apple.com/documentation/os/os_activity_scope_enter
func Os_activity_scope_leave ¶
func Os_activity_scope_leave(state Os_activity_scope_state_t)
Os_activity_scope_leave restores the current activity to a previously saved state.
See: https://developer.apple.com/documentation/os/os_activity_scope_leave
func Os_log_type_enabled ¶
func Os_log_type_enabled(oslog Os_log_t, type_ Os_log_type_t) bool
Os_log_type_enabled returns a Boolean value that indicates whether the log can write messages with the specified log type.
See: https://developer.apple.com/documentation/os/OSLog/isEnabled(type:)
func Os_security_config_get_for_proc ¶
func Os_security_config_get_for_proc(pid int32, config *OsSecurityConfig) int
Os_security_config_get_for_proc.
See: https://developer.apple.com/documentation/os/os_security_config_get_for_proc
func Os_security_config_get_for_task ¶
func Os_security_config_get_for_task(task kernel.Task_t, config *OsSecurityConfig) int
Os_security_config_get_for_task.
See: https://developer.apple.com/documentation/os/os_security_config_get_for_task
func Os_signpost_enabled ¶
Os_signpost_enabled returns a Boolean value that indicates whether signposts are in an enabled state for the specified log.
See: https://developer.apple.com/documentation/os/os_signpost_enabled
func Os_sync_wait_on_address ¶
func Os_sync_wait_on_address(addr unsafe.Pointer, value uint64, size uintptr, flags OsSyncWaitOnAddress) int
Os_sync_wait_on_address an atomic compare-and-wait operation, used to implement higher-level synchronization primitives.
See: https://developer.apple.com/documentation/os/os_sync_wait_on_address
func Os_sync_wait_on_address_with_deadline ¶
func Os_sync_wait_on_address_with_deadline(addr unsafe.Pointer, value uint64, size uintptr, flags OsSyncWaitOnAddress, clockid OsClockMachAbsolute, deadline uint64) int
Os_sync_wait_on_address_with_deadline an atomic compare-and-wait operation with a deadline, used to implement higher-level synchronization primitives.
See: https://developer.apple.com/documentation/os/os_sync_wait_on_address_with_deadline
func Os_sync_wait_on_address_with_timeout ¶
func Os_sync_wait_on_address_with_timeout(addr unsafe.Pointer, value uint64, size uintptr, flags OsSyncWaitOnAddress, clockid OsClockMachAbsolute, timeout_ns uint64) int
Os_sync_wait_on_address_with_timeout an atomic compare-and-wait operation with a timeout, used to implement higher-level synchronization primitives.
See: https://developer.apple.com/documentation/os/os_sync_wait_on_address_with_timeout
func Os_sync_wake_by_address_all ¶
func Os_sync_wake_by_address_all(addr unsafe.Pointer, size uintptr, flags OsSyncWakeByAddress) int
Os_sync_wake_by_address_all an atomic operation that wakes all threads blocked on a futex wait, used to implement higher-level synchronization primitives.
See: https://developer.apple.com/documentation/os/os_sync_wake_by_address_all
func Os_sync_wake_by_address_any ¶
func Os_sync_wake_by_address_any(addr unsafe.Pointer, size uintptr, flags OsSyncWakeByAddress) int
Os_sync_wake_by_address_any an atomic operation that wakes one thread blocked on a futex wait, used to implement higher-level synchronization primitives.
See: https://developer.apple.com/documentation/os/os_sync_wake_by_address_any
func Os_unfair_lock_assert_not_owner ¶
func Os_unfair_lock_assert_not_owner(lock *[4]byte)
Os_unfair_lock_assert_not_owner triggers an assertion if the calling thread owns the specified unfair lock.
See: https://developer.apple.com/documentation/os/os_unfair_lock_assert_not_owner
func Os_unfair_lock_assert_owner ¶
func Os_unfair_lock_assert_owner(lock *[4]byte)
Os_unfair_lock_assert_owner triggers an assertion if the calling thread doesn’t own the specified unfair lock.
See: https://developer.apple.com/documentation/os/os_unfair_lock_assert_owner
func Os_unfair_lock_lock ¶
func Os_unfair_lock_lock(lock Os_unfair_lock_t)
Os_unfair_lock_lock a low-level lock that allows waiters to block efficiently on contention.
See: https://developer.apple.com/documentation/os/os_unfair_lock_lock
func Os_unfair_lock_lock_with_flags ¶
func Os_unfair_lock_lock_with_flags(lock Os_unfair_lock_t, flags OsUnfairLockFlag)
Os_unfair_lock_lock_with_flags.
See: https://developer.apple.com/documentation/os/os_unfair_lock_lock_with_flags
func Os_unfair_lock_trylock ¶
func Os_unfair_lock_trylock(lock Os_unfair_lock_t) bool
Os_unfair_lock_trylock locks an unfair lock if it is not already locked.
See: https://developer.apple.com/documentation/os/os_unfair_lock_trylock
func Os_unfair_lock_unlock ¶
func Os_unfair_lock_unlock(lock Os_unfair_lock_t)
Os_unfair_lock_unlock unlocks an unfair lock.
See: https://developer.apple.com/documentation/os/os_unfair_lock_unlock
func Os_workgroup_cancel ¶
func Os_workgroup_cancel(wg Os_workgroup_t)
Os_workgroup_cancel cancels and invalidates the specified workgroup.
See: https://developer.apple.com/documentation/os/os_workgroup_cancel
func Os_workgroup_copy_port ¶
func Os_workgroup_copy_port(wg Os_workgroup_t, mach_port_out *uint32) int
Os_workgroup_copy_port returns the Mach port associated with the workgroup.
See: https://developer.apple.com/documentation/os/os_workgroup_copy_port
func Os_workgroup_get_working_arena ¶
func Os_workgroup_get_working_arena(wg Os_workgroup_t, index_out *Os_workgroup_index) unsafe.Pointer
Os_workgroup_get_working_arena retrieves the workgroup’s shared data, and the thread-specific index into that data.
See: https://developer.apple.com/documentation/os/os_workgroup_get_working_arena
func Os_workgroup_interval_finish ¶
func Os_workgroup_interval_finish(wg Os_workgroup_interval_t, data Os_workgroup_interval_data_t) int
Os_workgroup_interval_finish stops the current interval-based execution of the workgroup’s threads.
See: https://developer.apple.com/documentation/os/os_workgroup_interval_finish
func Os_workgroup_interval_start ¶
func Os_workgroup_interval_start(wg Os_workgroup_interval_t, start uint64, deadline uint64, data Os_workgroup_interval_data_t) int
Os_workgroup_interval_start starts the regular execution of the workgroup’s threads at the specified time.
See: https://developer.apple.com/documentation/os/os_workgroup_interval_start
func Os_workgroup_interval_update ¶
func Os_workgroup_interval_update(wg Os_workgroup_interval_t, deadline uint64, data Os_workgroup_interval_data_t) int
Os_workgroup_interval_update schedules a new deadline for workgroup threads that run at regular intervals.
See: https://developer.apple.com/documentation/os/os_workgroup_interval_update
func Os_workgroup_join ¶
func Os_workgroup_join(wg Os_workgroup_t, token_out Os_workgroup_join_token_t) int
Os_workgroup_join adds the current thread to the specified workgroup.
See: https://developer.apple.com/documentation/os/os_workgroup_join
func Os_workgroup_leave ¶
func Os_workgroup_leave(wg Os_workgroup_t, token Os_workgroup_join_token_t)
Os_workgroup_leave removes the current thread from the workgroup it previously joined.
See: https://developer.apple.com/documentation/os/os_workgroup_leave
func Os_workgroup_max_parallel_threads ¶
func Os_workgroup_max_parallel_threads(wg Os_workgroup_t, attr Os_workgroup_mpt_attr_t) int
Os_workgroup_max_parallel_threads returns the maximum number of threads that the system recommends you add to the specified workgroup.
See: https://developer.apple.com/documentation/os/os_workgroup_max_parallel_threads
func Os_workgroup_set_working_arena ¶
func Os_workgroup_set_working_arena(wg Os_workgroup_t, arena unsafe.Pointer, max_workers uint32, destructor Os_workgroup_working_arena_destructor_t) int
Os_workgroup_set_working_arena distributes a block of managed memory to the threads of a workgroup.
See: https://developer.apple.com/documentation/os/os_workgroup_set_working_arena
func Os_workgroup_testcancel ¶
func Os_workgroup_testcancel(wg Os_workgroup_t) bool
Os_workgroup_testcancel returns a Boolean value that indicates whether the workgroup is canceled.
See: https://developer.apple.com/documentation/os/os_workgroup_testcancel
Types ¶
type IOSLog ¶
type IOSLog interface {
objectivec.IObject
}
An interface definition for the OSLog class.
type IOS_object ¶
type IOS_object interface {
objectivec.IObject
}
An interface definition for the OS_object class.
type IOS_os_workgroup ¶
type IOS_os_workgroup interface {
IOS_object
}
An interface definition for the OS_os_workgroup class.
See: https://developer.apple.com/documentation/os/OS_os_workgroup
type IOS_os_workgroup_interval ¶
type IOS_os_workgroup_interval interface {
IOS_os_workgroup
OS_os_workgroup_intervalProtocol
}
An interface definition for the OS_os_workgroup_interval class.
See: https://developer.apple.com/documentation/os/OS_os_workgroup_interval-c.class
type IOS_os_workgroup_parallel ¶
type IOS_os_workgroup_parallel interface {
IOS_os_workgroup
OS_os_workgroup_parallelProtocol
}
An interface definition for the OS_os_workgroup_parallel class.
See: https://developer.apple.com/documentation/os/OS_os_workgroup_parallel-c.class
type OSActivityFlag ¶
type OSActivityFlag = Os_activity_flag_t
OSActivityFlag is a Go-name alias for Os_activity_flag_t.
type OSActivityID ¶
type OSActivityID = Os_activity_id_t
OSActivityID is a Go-name alias for Os_activity_id_t.
type OSActivityScopeState ¶
type OSActivityScopeState = Os_activity_scope_state_t
OSActivityScopeState is a Go-name alias for Os_activity_scope_state_t.
type OSLog ¶
type OSLog struct {
objectivec.Object
}
A container of related log messages.
Overview ¶
A log categorizes the messages you write and makes it easy to sort and filter them. Each log contains a subsystem and a category, which you define. A subsystem identifies a major functional area of your app, which you specify using reverse DNS notation, such as `com.Your_companyXCUIElementTypeYour_subsystem_name()`. A category segregates specific areas within a subsystem.
See: https://developer.apple.com/documentation/os/OSLog
func OSLogFromID ¶
OSLogFromID constructs a OSLog from an objc.ID.
A container of related log messages.
func (OSLog) Autorelease ¶
Autorelease adds the receiver to the current autorelease pool.
type OSLogClass ¶
type OSLogClass struct {
// contains filtered or unexported fields
}
func GetOSLogClass ¶
func GetOSLogClass() OSLogClass
GetOSLogClass returns the class object for OSLog.
func (OSLogClass) Alloc ¶
func (oc OSLogClass) Alloc() OSLog
Alloc allocates memory for a new instance of the class.
func (OSLogClass) Class ¶
func (oc OSLogClass) Class() objc.Class
Class returns the underlying Objective-C class pointer.
type OSSecurityConfig ¶
type OSSecurityConfig = Os_security_config_t
OSSecurityConfig is a Go-name alias for Os_security_config_t.
type OSSignpostID ¶
type OSSignpostID = Os_signpost_id_t
OSSignpostID is a Go-name alias for Os_signpost_id_t.
type OSSignpostType ¶
type OSSignpostType = Os_signpost_type_t
OSSignpostType is a Go-name alias for Os_signpost_type_t.
type OSSyncWaitOnAddressFlags ¶
type OSSyncWaitOnAddressFlags = Os_sync_wait_on_address_flags_t
OSSyncWaitOnAddressFlags is a Go-name alias for Os_sync_wait_on_address_flags_t.
type OSSyncWakeByAddressFlags ¶
type OSSyncWakeByAddressFlags = Os_sync_wake_by_address_flags_t
OSSyncWakeByAddressFlags is a Go-name alias for Os_sync_wake_by_address_flags_t.
type OSUnfairLock ¶
type OSUnfairLock = Os_unfair_lock_t
OSUnfairLock is a Go-name alias for Os_unfair_lock_t.
type OSUnfairLockFlags ¶
type OSUnfairLockFlags = Os_unfair_lock_flags_t
OSUnfairLockFlags is a Go-name alias for Os_unfair_lock_flags_t.
type OSWorkgroup ¶
type OSWorkgroup = Os_workgroup_t
OSWorkgroup is a Go-name alias for Os_workgroup_t.
type OSWorkgroupAttr ¶
type OSWorkgroupAttr = Os_workgroup_attr_t
OSWorkgroupAttr is a Go-name alias for Os_workgroup_attr_t.
type OSWorkgroupAttrS ¶
type OSWorkgroupAttrS = Os_workgroup_attr_s
OSWorkgroupAttrS is a Go-name alias for Os_workgroup_attr_s.
type OSWorkgroupIndex ¶
type OSWorkgroupIndex = Os_workgroup_index
OSWorkgroupIndex is a Go-name alias for Os_workgroup_index.
type OSWorkgroupInterval ¶
type OSWorkgroupInterval = Os_workgroup_interval_t
OSWorkgroupInterval is a Go-name alias for Os_workgroup_interval_t.
type OSWorkgroupIntervalData ¶
type OSWorkgroupIntervalData = Os_workgroup_interval_data_t
OSWorkgroupIntervalData is a Go-name alias for Os_workgroup_interval_data_t.
type OSWorkgroupIntervalDataS ¶
type OSWorkgroupIntervalDataS = Os_workgroup_interval_data_s
OSWorkgroupIntervalDataS is a Go-name alias for Os_workgroup_interval_data_s.
type OSWorkgroupJoinToken ¶
type OSWorkgroupJoinToken = Os_workgroup_join_token_t
OSWorkgroupJoinToken is a Go-name alias for Os_workgroup_join_token_t.
type OSWorkgroupJoinTokenS ¶
type OSWorkgroupJoinTokenS = Os_workgroup_join_token_s
OSWorkgroupJoinTokenS is a Go-name alias for Os_workgroup_join_token_s.
type OSWorkgroupMptAttr ¶
type OSWorkgroupMptAttr = Os_workgroup_mpt_attr_t
OSWorkgroupMptAttr is a Go-name alias for Os_workgroup_mpt_attr_t.
type OSWorkgroupMptAttrS ¶
type OSWorkgroupMptAttrS = Os_workgroup_mpt_attr_s
OSWorkgroupMptAttrS is a Go-name alias for Os_workgroup_mpt_attr_s.
type OSWorkgroupParallel ¶
type OSWorkgroupParallel = Os_workgroup_parallel_t
OSWorkgroupParallel is a Go-name alias for Os_workgroup_parallel_t.
type OSWorkgroupWorkingArenaDestructor ¶
type OSWorkgroupWorkingArenaDestructor = Os_workgroup_working_arena_destructor_t
OSWorkgroupWorkingArenaDestructor is a Go-name alias for Os_workgroup_working_arena_destructor_t.
type OS_object ¶
type OS_object struct {
objectivec.Object
}
See: https://developer.apple.com/documentation/os/OS_object
func OS_objectFromID ¶
OS_objectFromID constructs a OS_object from an objc.ID.
func (OS_object) Autorelease ¶
Autorelease adds the receiver to the current autorelease pool.
type OS_objectClass ¶
type OS_objectClass struct {
// contains filtered or unexported fields
}
func GetOS_objectClass ¶
func GetOS_objectClass() OS_objectClass
GetOS_objectClass returns the class object for OS_object.
func (OS_objectClass) Alloc ¶
func (oc OS_objectClass) Alloc() OS_object
Alloc allocates memory for a new instance of the class.
func (OS_objectClass) Class ¶
func (oc OS_objectClass) Class() objc.Class
Class returns the underlying Objective-C class pointer.
type OS_os_activity ¶
type OS_os_activity interface {
objectivec.IObject
}
OS_os_activity protocol.
See: https://developer.apple.com/documentation/os/OS_os_activity
type OS_os_activityObject ¶
type OS_os_activityObject struct {
objectivec.Object
}
OS_os_activityObject wraps an existing Objective-C object that conforms to the OS_os_activity protocol.
func OS_os_activityObjectFromID ¶
func OS_os_activityObjectFromID(id objc.ID) OS_os_activityObject
OS_os_activityObjectFromID constructs a OS_os_activityObject from an objc.ID. The object is determined to conform to the protocol at runtime.
func (OS_os_activityObject) BaseObject ¶
func (o OS_os_activityObject) BaseObject() objectivec.Object
type OS_os_logObject ¶
type OS_os_logObject struct {
objectivec.Object
}
OS_os_logObject wraps an existing Objective-C object that conforms to the OS_os_log protocol.
func OS_os_logObjectFromID ¶
func OS_os_logObjectFromID(id objc.ID) OS_os_logObject
OS_os_logObjectFromID constructs a OS_os_logObject from an objc.ID. The object is determined to conform to the protocol at runtime.
func (OS_os_logObject) BaseObject ¶
func (o OS_os_logObject) BaseObject() objectivec.Object
type OS_os_workgroup ¶
type OS_os_workgroup struct {
OS_object
}
See: https://developer.apple.com/documentation/os/OS_os_workgroup
func NewOS_os_workgroup ¶
func NewOS_os_workgroup() OS_os_workgroup
NewOS_os_workgroup creates a new OS_os_workgroup instance.
func OS_os_workgroupFromID ¶
func OS_os_workgroupFromID(id objc.ID) OS_os_workgroup
OS_os_workgroupFromID constructs a OS_os_workgroup from an objc.ID.
func (OS_os_workgroup) Autorelease ¶
func (o OS_os_workgroup) Autorelease() OS_os_workgroup
Autorelease adds the receiver to the current autorelease pool.
func (OS_os_workgroup) Init ¶
func (o OS_os_workgroup) Init() OS_os_workgroup
Init initializes the instance.
type OS_os_workgroupClass ¶
type OS_os_workgroupClass struct {
// contains filtered or unexported fields
}
func GetOS_os_workgroupClass ¶
func GetOS_os_workgroupClass() OS_os_workgroupClass
GetOS_os_workgroupClass returns the class object for OS_os_workgroup.
func (OS_os_workgroupClass) Alloc ¶
func (oc OS_os_workgroupClass) Alloc() OS_os_workgroup
Alloc allocates memory for a new instance of the class.
func (OS_os_workgroupClass) Class ¶
func (oc OS_os_workgroupClass) Class() objc.Class
Class returns the underlying Objective-C class pointer.
type OS_os_workgroup_interval ¶
type OS_os_workgroup_interval struct {
OS_os_workgroup
}
See: https://developer.apple.com/documentation/os/OS_os_workgroup_interval-c.class
func NewOS_os_workgroup_interval ¶
func NewOS_os_workgroup_interval() OS_os_workgroup_interval
NewOS_os_workgroup_interval creates a new OS_os_workgroup_interval instance.
func OS_os_workgroup_intervalFromID ¶
func OS_os_workgroup_intervalFromID(id objc.ID) OS_os_workgroup_interval
OS_os_workgroup_intervalFromID constructs a OS_os_workgroup_interval from an objc.ID.
func (OS_os_workgroup_interval) Autorelease ¶
func (o OS_os_workgroup_interval) Autorelease() OS_os_workgroup_interval
Autorelease adds the receiver to the current autorelease pool.
func (OS_os_workgroup_interval) Init ¶
func (o OS_os_workgroup_interval) Init() OS_os_workgroup_interval
Init initializes the instance.
type OS_os_workgroup_intervalClass ¶
type OS_os_workgroup_intervalClass struct {
// contains filtered or unexported fields
}
func GetOS_os_workgroup_intervalClass ¶
func GetOS_os_workgroup_intervalClass() OS_os_workgroup_intervalClass
GetOS_os_workgroup_intervalClass returns the class object for OS_os_workgroup_interval.
func (OS_os_workgroup_intervalClass) Alloc ¶
func (oc OS_os_workgroup_intervalClass) Alloc() OS_os_workgroup_interval
Alloc allocates memory for a new instance of the class.
func (OS_os_workgroup_intervalClass) Class ¶
func (oc OS_os_workgroup_intervalClass) Class() objc.Class
Class returns the underlying Objective-C class pointer.
type OS_os_workgroup_intervalProtocol ¶
type OS_os_workgroup_intervalProtocol interface {
objectivec.IObject
}
OS_os_workgroup_interval protocol.
See: https://developer.apple.com/documentation/os/OS_os_workgroup_interval-c.protocol
type OS_os_workgroup_intervalProtocolObject ¶
type OS_os_workgroup_intervalProtocolObject struct {
objectivec.Object
}
OS_os_workgroup_intervalProtocolObject wraps an existing Objective-C object that conforms to the OS_os_workgroup_intervalProtocol protocol.
func OS_os_workgroup_intervalProtocolObjectFromID ¶
func OS_os_workgroup_intervalProtocolObjectFromID(id objc.ID) OS_os_workgroup_intervalProtocolObject
OS_os_workgroup_intervalProtocolObjectFromID constructs a OS_os_workgroup_intervalProtocolObject from an objc.ID. The object is determined to conform to the protocol at runtime.
func (OS_os_workgroup_intervalProtocolObject) BaseObject ¶
func (o OS_os_workgroup_intervalProtocolObject) BaseObject() objectivec.Object
type OS_os_workgroup_parallel ¶
type OS_os_workgroup_parallel struct {
OS_os_workgroup
}
See: https://developer.apple.com/documentation/os/OS_os_workgroup_parallel-c.class
func NewOS_os_workgroup_parallel ¶
func NewOS_os_workgroup_parallel() OS_os_workgroup_parallel
NewOS_os_workgroup_parallel creates a new OS_os_workgroup_parallel instance.
func OS_os_workgroup_parallelFromID ¶
func OS_os_workgroup_parallelFromID(id objc.ID) OS_os_workgroup_parallel
OS_os_workgroup_parallelFromID constructs a OS_os_workgroup_parallel from an objc.ID.
func (OS_os_workgroup_parallel) Autorelease ¶
func (o OS_os_workgroup_parallel) Autorelease() OS_os_workgroup_parallel
Autorelease adds the receiver to the current autorelease pool.
func (OS_os_workgroup_parallel) Init ¶
func (o OS_os_workgroup_parallel) Init() OS_os_workgroup_parallel
Init initializes the instance.
type OS_os_workgroup_parallelClass ¶
type OS_os_workgroup_parallelClass struct {
// contains filtered or unexported fields
}
func GetOS_os_workgroup_parallelClass ¶
func GetOS_os_workgroup_parallelClass() OS_os_workgroup_parallelClass
GetOS_os_workgroup_parallelClass returns the class object for OS_os_workgroup_parallel.
func (OS_os_workgroup_parallelClass) Alloc ¶
func (oc OS_os_workgroup_parallelClass) Alloc() OS_os_workgroup_parallel
Alloc allocates memory for a new instance of the class.
func (OS_os_workgroup_parallelClass) Class ¶
func (oc OS_os_workgroup_parallelClass) Class() objc.Class
Class returns the underlying Objective-C class pointer.
type OS_os_workgroup_parallelProtocol ¶
type OS_os_workgroup_parallelProtocol interface {
objectivec.IObject
}
OS_os_workgroup_parallel protocol.
See: https://developer.apple.com/documentation/os/OS_os_workgroup_parallel-c.protocol
type OS_os_workgroup_parallelProtocolObject ¶
type OS_os_workgroup_parallelProtocolObject struct {
objectivec.Object
}
OS_os_workgroup_parallelProtocolObject wraps an existing Objective-C object that conforms to the OS_os_workgroup_parallelProtocol protocol.
func OS_os_workgroup_parallelProtocolObjectFromID ¶
func OS_os_workgroup_parallelProtocolObjectFromID(id objc.ID) OS_os_workgroup_parallelProtocolObject
OS_os_workgroup_parallelProtocolObjectFromID constructs a OS_os_workgroup_parallelProtocolObject from an objc.ID. The object is determined to conform to the protocol at runtime.
func (OS_os_workgroup_parallelProtocolObject) BaseObject ¶
func (o OS_os_workgroup_parallelProtocolObject) BaseObject() objectivec.Object
type OsActivityFlag ¶
type OsActivityFlag uint
const ( // OS_ACTIVITY_FLAG_DEFAULT: Creates a new activity and associates it as a child of any provided parent activity. OS_ACTIVITY_FLAG_DEFAULT OsActivityFlag = 0 // OS_ACTIVITY_FLAG_DETACHED: Creates a new activity that is independent of any provided parent activity. OS_ACTIVITY_FLAG_DETACHED OsActivityFlag = 0x1 // OS_ACTIVITY_FLAG_IF_NONE_PRESENT: Creates a new activity only if one is not already present. OS_ACTIVITY_FLAG_IF_NONE_PRESENT OsActivityFlag = 0x2 )
func (OsActivityFlag) String ¶
func (e OsActivityFlag) String() string
type OsClockMachAbsolute ¶
type OsClockMachAbsolute uint
const ( // OS_CLOCK_MACH_ABSOLUTE_TIME: Units relative to Mach absolute time value. OS_CLOCK_MACH_ABSOLUTE_TIME OsClockMachAbsolute = 32 )
func (OsClockMachAbsolute) String ¶
func (e OsClockMachAbsolute) String() string
type OsLogType ¶
type OsLogType uint
const ( // OS_LOG_TYPE_DEBUG: The debug log level. OS_LOG_TYPE_DEBUG OsLogType = 0x2 // OS_LOG_TYPE_DEFAULT: The default log level. OS_LOG_TYPE_DEFAULT OsLogType = 0 // OS_LOG_TYPE_ERROR: The error log level. OS_LOG_TYPE_ERROR OsLogType = 0x10 // OS_LOG_TYPE_FAULT: The fault log level. OS_LOG_TYPE_FAULT OsLogType = 0x11 // OS_LOG_TYPE_INFO: The informational log level. OS_LOG_TYPE_INFO OsLogType = 0x1 )
type OsSecurityConfig ¶
type OsSecurityConfig uint
const ( // OS_SECURITY_CONFIG_GUARD_OBJECTS: # Discussion OS_SECURITY_CONFIG_GUARD_OBJECTS OsSecurityConfig = 0 // OS_SECURITY_CONFIG_HARDENED_HEAP: # Discussion OS_SECURITY_CONFIG_HARDENED_HEAP OsSecurityConfig = 0 // OS_SECURITY_CONFIG_MTE: # Discussion OS_SECURITY_CONFIG_MTE OsSecurityConfig = 0 // OS_SECURITY_CONFIG_NONE: # Discussion OS_SECURITY_CONFIG_NONE OsSecurityConfig = 0 // OS_SECURITY_CONFIG_TPRO: # Discussion OS_SECURITY_CONFIG_TPRO OsSecurityConfig = 0 )
func Os_security_config_get ¶
func Os_security_config_get() OsSecurityConfig
Os_security_config_get.
See: https://developer.apple.com/documentation/os/os_security_config_get
func (OsSecurityConfig) String ¶
func (e OsSecurityConfig) String() string
type OsSignpost ¶
type OsSignpost uint
const ( // OS_SIGNPOST_EVENT: A signpost that marks an event in your code. OS_SIGNPOST_EVENT OsSignpost = 0 // OS_SIGNPOST_INTERVAL_BEGIN: A signpost that marks the start of a time interval of interest in your code. OS_SIGNPOST_INTERVAL_BEGIN OsSignpost = 0x1 // OS_SIGNPOST_INTERVAL_END: A signpost that marks the end of a time interval of interest in your code. OS_SIGNPOST_INTERVAL_END OsSignpost = 0x2 )
func (OsSignpost) String ¶
func (e OsSignpost) String() string
type OsSyncWaitOnAddress ¶
type OsSyncWaitOnAddress uint
const ( // OS_SYNC_WAIT_ON_ADDRESS_NONE: Default behavior for futex functions that block a thread. OS_SYNC_WAIT_ON_ADDRESS_NONE OsSyncWaitOnAddress = 0 // OS_SYNC_WAIT_ON_ADDRESS_SHARED: Flag to indicate an address is in a shared memory region, allowing for a futex wake from another process. OS_SYNC_WAIT_ON_ADDRESS_SHARED OsSyncWaitOnAddress = 0 )
func (OsSyncWaitOnAddress) String ¶
func (e OsSyncWaitOnAddress) String() string
type OsSyncWakeByAddress ¶
type OsSyncWakeByAddress uint
const ( // OS_SYNC_WAKE_BY_ADDRESS_NONE: The default behavior for futex functions that wake a thread. OS_SYNC_WAKE_BY_ADDRESS_NONE OsSyncWakeByAddress = 0 // OS_SYNC_WAKE_BY_ADDRESS_SHARED: A flag to indicate an address is in a shared memory region, allowing you to wake another waiting process. OS_SYNC_WAKE_BY_ADDRESS_SHARED OsSyncWakeByAddress = 0 )
func (OsSyncWakeByAddress) String ¶
func (e OsSyncWakeByAddress) String() string
type OsUnfairLockFlag ¶
type OsUnfairLockFlag uint
const ( OS_UNFAIR_LOCK_FLAG_ADAPTIVE_SPIN OsUnfairLockFlag = 0x40000 OS_UNFAIR_LOCK_FLAG_NONE OsUnfairLockFlag = 0 )
func (OsUnfairLockFlag) String ¶
func (e OsUnfairLockFlag) String() string
type Os_activity_flag_t ¶
type Os_activity_flag_t = OsActivityFlag
type Os_activity_id_t ¶
type Os_activity_id_t = uint64
Os_activity_id_t is a number that uniquely identifies an activity.
See: https://developer.apple.com/documentation/os/os_activity_id_t
func Os_activity_get_identifier ¶
func Os_activity_get_identifier(activity Os_activity_t, parent_id *Os_activity_id_t) Os_activity_id_t
Os_activity_get_identifier retrieves the identifier for a given activity object.
See: https://developer.apple.com/documentation/os/os_activity_get_identifier
type Os_activity_scope_state_s ¶
type Os_activity_scope_state_s struct {
Opaque uint64 // Opaque data that the system uses to store the execution state.
}
Os_activity_scope_state_s
[Full Topic] [Full Topic]: https://developer.apple.com/documentation/os/os_activity_scope_state_s
type Os_activity_scope_state_t ¶
type Os_activity_scope_state_t = uintptr
Os_activity_scope_state_t is an opaque structure that contains a saved activity-execution context.
See: https://developer.apple.com/documentation/os/os_activity_scope_state_t
type Os_activity_t ¶
type Os_activity_t = objectivec.Object
Os_activity_t is an object that represents an activity triggered by the user.
See: https://developer.apple.com/documentation/os/os_activity_t
type Os_block_t ¶
type Os_block_t = func()
Os_block_t is a block that takes no arguments and returns no value.
See: https://developer.apple.com/documentation/os/os_block_t
type Os_clockid_t ¶
type Os_clockid_t = OsClockMachAbsolute
type Os_function_t ¶
Os_function_t is a pointer to a function.
See: https://developer.apple.com/documentation/os/os_function_t
type Os_log_t ¶
type Os_log_t = objectivec.Object
Os_log_t is a log object that you pass to logging functions to send messages to that log.
See: https://developer.apple.com/documentation/os/os_log_t
func Os_log_create ¶
Os_log_create creates a custom log object.
See: https://developer.apple.com/documentation/os/os_log_create
type Os_log_type_t ¶
type Os_log_type_t = OsLogType
type Os_security_config_t ¶
type Os_security_config_t = OsSecurityConfig
type Os_signpost_id_t ¶
type Os_signpost_id_t = uint64
Os_signpost_id_t is an identifier you use to distinguish between signposts that have the same name and destination log.
See: https://developer.apple.com/documentation/os/os_signpost_id_t
func Os_signpost_id_generate ¶
func Os_signpost_id_generate(log Os_log_t) Os_signpost_id_t
Os_signpost_id_generate creates a signpost identifier that’s unique among signposts logged to a specified log.
See: https://developer.apple.com/documentation/os/os_signpost_id_generate
func Os_signpost_id_make_with_pointer ¶
func Os_signpost_id_make_with_pointer(log Os_log_t, ptr unsafe.Pointer) Os_signpost_id_t
Os_signpost_id_make_with_pointer creates a signpost identifier that’s unique among signposts logging to the specified log, using a pointer value to generate the unique value.
See: https://developer.apple.com/documentation/os/os_signpost_id_make_with_pointer
type Os_signpost_type_t ¶
type Os_signpost_type_t = OsSignpost
type Os_sync_wait_on_address_flags_t ¶
type Os_sync_wait_on_address_flags_t = OsSyncWaitOnAddress
type Os_sync_wake_by_address_flags_t ¶
type Os_sync_wake_by_address_flags_t = OsSyncWakeByAddress
type Os_unfair_lock_flags_t ¶
type Os_unfair_lock_flags_t = OsUnfairLockFlag
type Os_unfair_lock_t ¶
type Os_unfair_lock_t = uintptr
Os_unfair_lock_t is a pointer to an unfair lock structure.
See: https://developer.apple.com/documentation/os/os_unfair_lock_t
type Os_workgroup_attr_opaque_s ¶
Os_workgroup_attr_opaque_s
[Full Topic] [Full Topic]: https://developer.apple.com/documentation/os/os_workgroup_attr_opaque_s
type Os_workgroup_attr_s ¶
type Os_workgroup_attr_s = Os_workgroup_attr_opaque_s
See: https://developer.apple.com/documentation/os/os_workgroup_attr_s
type Os_workgroup_attr_t ¶
type Os_workgroup_attr_t = uintptr
Os_workgroup_attr_t is an opaque structure for storing workgroup-related attributes.
See: https://developer.apple.com/documentation/os/os_workgroup_attr_t
type Os_workgroup_index ¶
type Os_workgroup_index = uint32
Os_workgroup_index is a unique index that the workgroup assigns to its joined threads.
See: https://developer.apple.com/documentation/os/os_workgroup_index
type Os_workgroup_interval_data_opaque_s ¶
Os_workgroup_interval_data_opaque_s
[Full Topic] [Full Topic]: https://developer.apple.com/documentation/os/os_workgroup_interval_data_opaque_s
type Os_workgroup_interval_data_s ¶
type Os_workgroup_interval_data_s = Os_workgroup_interval_data_opaque_s
See: https://developer.apple.com/documentation/os/os_workgroup_interval_data_s
type Os_workgroup_interval_data_t ¶
type Os_workgroup_interval_data_t = uintptr
Os_workgroup_interval_data_t is an opaque structure that contains additional configuration data for the interval workgroup.
See: https://developer.apple.com/documentation/os/os_workgroup_interval_data_t
type Os_workgroup_interval_t ¶
Os_workgroup_interval_t is a workgroup object that supports the scheduling of threads on a repeating cadence.
See: https://developer.apple.com/documentation/os/os_workgroup_interval_t
type Os_workgroup_join_token_opaque_s ¶
Os_workgroup_join_token_opaque_s
[Full Topic] [Full Topic]: https://developer.apple.com/documentation/os/os_workgroup_join_token_opaque_s
type Os_workgroup_join_token_s ¶
type Os_workgroup_join_token_s = Os_workgroup_join_token_opaque_s
See: https://developer.apple.com/documentation/os/os_workgroup_join_token_s
type Os_workgroup_join_token_t ¶
type Os_workgroup_join_token_t = uintptr
Os_workgroup_join_token_t is an opaque token that represents a connection between a thread and a workgroup.
See: https://developer.apple.com/documentation/os/os_workgroup_join_token_t
type Os_workgroup_mpt_attr_s ¶
See: https://developer.apple.com/documentation/os/os_workgroup_mpt_attr_s
type Os_workgroup_mpt_attr_t ¶
type Os_workgroup_mpt_attr_t = uintptr
Os_workgroup_mpt_attr_t is an opaque structure containing attributes related to a request for the maximum number of parallel threads.
See: https://developer.apple.com/documentation/os/os_workgroup_mpt_attr_t
type Os_workgroup_parallel_t ¶
Os_workgroup_parallel_t is a workgroup object that supports the scheduling of threads that work in parallel to complete a task.
See: https://developer.apple.com/documentation/os/os_workgroup_parallel_t
func Os_workgroup_parallel_create ¶
func Os_workgroup_parallel_create(name string, attr Os_workgroup_attr_t) Os_workgroup_parallel_t
Os_workgroup_parallel_create creates a new workgroup that manges threads working on a single task in parallel.
See: https://developer.apple.com/documentation/os/os_workgroup_parallel_create
type Os_workgroup_t ¶
type Os_workgroup_t = *OS_os_workgroup
Os_workgroup_t is an opaque object representing a default workgroup in the current process.
See: https://developer.apple.com/documentation/os/os_workgroup_t
func Os_workgroup_create_with_port ¶
func Os_workgroup_create_with_port(name string, mach_port uint32) Os_workgroup_t
Os_workgroup_create_with_port creates a new workgroup that is bound to the workgroup with the specified Mach port.
See: https://developer.apple.com/documentation/os/os_workgroup_create_with_port
func Os_workgroup_create_with_workgroup ¶
func Os_workgroup_create_with_workgroup(name string, wg Os_workgroup_t) Os_workgroup_t
Os_workgroup_create_with_workgroup create a new workgroup that is bound to the specified workgroup.
See: https://developer.apple.com/documentation/os/os_workgroup_create_with_workgroup
type Os_workgroup_working_arena_destructor_t ¶
Os_workgroup_working_arena_destructor_t is a function that deallocates a workgroup’s currently assigned shared memory.
See: https://developer.apple.com/documentation/os/os_workgroup_working_arena_destructor_t
Source Files
¶
- blocks.gen.go
- doc.gen.go
- enums.gen.go
- functions.gen.go
- generate.go
- os_log.gen.go
- os_object.gen.go
- os_os_activity_protocol.gen.go
- os_os_log_protocol.gen.go
- os_os_workgroup.gen.go
- os_os_workgroup_interval.gen.go
- os_os_workgroup_interval_protocol.gen.go
- os_os_workgroup_parallel.gen.go
- os_os_workgroup_parallel_protocol.gen.go
- typedefs.gen.go
- types.gen.go
- undefined_types.gen.go