Documentation
¶
Overview ¶
Package capture provides generic image conversion and processing helpers.
Index ¶
- func EncodeJPEG(img image.Image, quality int) ([]byte, error)
- func EncodePNG(img image.Image) ([]byte, error)
- func GenerateDiff(old, new image.Image) image.Image
- func GoImageFromCGImage(cgImage coregraphics.CGImageRef, cropTopPx int) (image.Image, error)
- func ScaleImage(img image.Image, scale float64) image.Image
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func EncodeJPEG ¶
EncodeJPEG encodes img as JPEG with quality.
func GenerateDiff ¶
GenerateDiff creates a diff image highlighting changes between two images.
func GoImageFromCGImage ¶
func GoImageFromCGImage(cgImage coregraphics.CGImageRef, cropTopPx int) (image.Image, error)
GoImageFromCGImage converts a CGImageRef to a Go image.Image.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.