Documentation
¶
Overview ¶
Package platform provides generic VM platform helpers for Apple Virtualization VMs.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CreateEFIBootLoader ¶
func CreateEFIBootLoader(path string) (vz.VZEFIBootLoader, bool, error)
CreateEFIBootLoader creates an EFI boot loader with a variable store at path.
func LoadOrCreateGenericMachineIdentifier ¶
func LoadOrCreateGenericMachineIdentifier(path string) (vz.VZGenericMachineIdentifier, bool, error)
LoadOrCreateGenericMachineIdentifier loads a generic machine identifier from path or creates and saves a new one.
func SaveGenericMachineIdentifier ¶
func SaveGenericMachineIdentifier(machineID vz.VZGenericMachineIdentifier, path string) error
SaveGenericMachineIdentifier saves a generic machine identifier to path.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.